"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const log_1 = require("../common/log");
const util_1 = require("../common/util");
const child_process_1 = require("child_process");
exports.command = "test";
exports.desc = "单元测试";
exports.builder = (yargs) => {
    return yargs
        .option("p", {
        alias: "path",
        describe: "测试的目录",
        default: ".",
        type: "string"
    })
        .usage("Usage: $0 test -p .");
};
exports.handler = (yargs) => {
    log_1.printMessage("单元测试开始...");
    let projectPath = path.resolve(yargs.p) || process.cwd();
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let mocha = util_1.getCreateProjectDependencies(projectPath, path.join("mocha", "bin", "mocha"));
    let options = {
        encoding: "utf8",
        cwd: projectPath,
        stdio: [process.stdin, process.stdout, process.stderr]
    };
    let childProcess = child_process_1.spawnSync(nyc, [mocha, "-t", "5000"], options);
    if (childProcess.status !== 0) {
        log_1.printErrorMessage("单元测试失败！");
        process.exit(childProcess.status);
        return;
    }
    log_1.printMessage("单元测试成功结束");
    let commandText = `"${nyc}" report --reporter=text-lcov`;
    let res = child_process_1.execSync(commandText, { encoding: "utf-8", cwd: projectPath });
    log_1.printMessage("覆盖率完成");
};
//# sourceMappingURL=test.js.map